isRaw property
Whether a raw image (without 623-byte jpeg header) will be returned from Frame, hence the corresponding header should be added Note that the first request for an image with a given resolution and quality level MUST be a complete image so the jpeg header can be saved and used for subsequent raw images of the same resolution and quality level
Implementation
final bool isRaw;